# CAD Exchanger Web Toolkit

The CAD Exchanger Web Toolkit is a JavaScript library to visualize, explore and analyze 3D CAD models. Web Toolkit can be used to develop web applications running publicly or on premise (i.e. inside a corporate network).

The CAD Exchanger Web Toolkit is used as an underlying engine of [CAD Exchanger Online Viewer](https://viewer.cadexchanger.com/).

<div style="margin-bottom: 2rem;" align="center">
<img src="https://docs.cadexchanger.com/web-toolkit/webtoolkit-based-app.png" alt="CAD Exchanger Web Toolkit based application" width=320 style="display:block">
<span style="font-size: 0.8125rem;">CAD Exchanger Web Toolkit based application</span>
</div>

## Key Features

The CAD Exchanger Web Toolkit provides the following features:

* Support of 30+ <a href="https://cadexchanger.com/formats/" target="_blank">3D formats</a> (with the help of <a href="https://cadexchanger.com/products/sdk/" target="_blank">CAD Exchanger SDK</a>).
* Access to product structure of assemblies and parts.
* Support of B-Rep (Boundary Representation) and mesh (tessellated) geometry.
* Access to metadata: names, user-defined properties, id’s, etc.
* Visualization of colors, materials, textures and transparencies.
* Measurements: bounding boxes, distances, angles. (With the help of <a href="https://cadexchanger.com/products/sdk/" target="_blank">CAD Exchanger SDK</a>, additional measurements are available such as surface area, volume, centroid, minimum bounding box, etc.)
* Reading of PMI (Product and Manufacturing Information).
* Multiple display modes, including shading, wireframe and ghost views.
* Interactive selection and hovering in 3D view.

## Installation

Web Toolkit can be installed from [npm](https://www.npmjs.com/package/@cadexchanger/web-toolkit) and CDN.

### Install from NPM

To install the Web Toolkit npm module, open your project folder in a terminal and run:

```sh
npm install --save @cadexchanger/web-toolkit
```

The package will be downloaded and installed.

There are two options to include WTK to your project:

```js
// Option 1: Import the entire library.
import cadex from '@cadexchanger/web-toolkit';

const model = new cadex.ModelData_Model();

// Option 2: Import just the parts you need.
import { ModelData_Model } from '@cadexchanger/web-toolkit';

const model = new ModelData_Model();
```

### Install from CDN

To install from CDN simply add the following lines:

```html
<!-- Load minified bundle library which includes all necessary dependencies -->
<script src="https://cdn.skypack.dev/@cadexchanger/web-toolkit?min"></script>

<script type="text/javascript">
  const model = new cadex.ModelData_Model();
</script>
```

## Documentation

You can find the Web Toolkit documentation [on the website](https://docs.cadexchanger.com/web-toolkit).

## Questions

For questions and support please submit your inquiry via [contact form](https://cadexchanger.com/contact-us/).
